@@ -21,12 +21,18 @@
 */
 
 #include <config.h>
+#ifdef GNOME_GTKHTML_EDITOR_SHLIB
+#include <glib/gi18n-lib.h>
+#else
 #include <glib/gi18n.h>
+#endif
 #include <gnome.h>
 #include <libgnomeui/gnome-window-icon.h>
 #include "replace.h"
 #include "dialog.h"
 #include "htmlengine.h"
+#include "gtkhtml-private.h"
+
 
 struct _GtkHTMLReplaceAskDialog {
 	GtkDialog  *dialog;
@@ -71,6 +77,7 @@ static GtkHTMLReplaceAskDialog *
 ask_dialog_new (HTMLEngine *e)
 {
 	GtkHTMLReplaceAskDialog *d;
+	char *filename;
 
 	d = g_new (GtkHTMLReplaceAskDialog, 1);
 	/* we use CANCEL response for close, because we want Esc to close the dialog - see gtkdialog.c */
@@ -83,7 +90,10 @@ ask_dialog_new (HTMLEngine *e)
 	d->engine = e;
 	d->finished = FALSE;
 
-	gnome_window_icon_set_from_file (GTK_WINDOW (d->dialog), ICONDIR "/search-and-replace-24.png");
+	filename = g_build_filename (ICONDIR, "search-and-replace-24.png", NULL);
+	gnome_window_icon_set_from_file (GTK_WINDOW (d->dialog), filename);
+	g_free (filename);
+
 	g_signal_connect (d->dialog, "response", G_CALLBACK (ask_dialog_response), d);
 
 	return d;
@@ -158,6 +168,7 @@ gtk_html_replace_dialog_new (GtkHTML *html, GtkHTMLControlData *cd)
 	GtkWidget *hbox, *vbox;
 	GtkWidget *table;
 	GtkWidget *label;
+	gchar *filename;
 
 	/* we use CANCEL response for close, because we want Esc to close the dialog - see gtkdialog.c */
 	dialog->dialog         = GTK_DIALOG (gtk_dialog_new_with_buttons (_("Replace"), NULL, 0,
@@ -180,11 +191,11 @@ gtk_html_replace_dialog_new (GtkHTML *html, GtkHTMLControlData *cd)
 
 	gtk_table_set_col_spacings (GTK_TABLE (table), 3);
 	label = gtk_label_new_with_mnemonic (_("R_eplace:"));
-	gtk_label_set_mnemonic_widget (label,dialog-> entry_search);
+	gtk_label_set_mnemonic_widget ((GtkLabel *)label,dialog-> entry_search);
 	gtk_misc_set_alignment (GTK_MISC (label), .0, .5);
 	gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 1, GTK_FILL, GTK_FILL, 0, 0);
 	label = gtk_label_new_with_mnemonic (_("_With:"));
-	gtk_label_set_mnemonic_widget (label, dialog->entry_replace);
+	gtk_label_set_mnemonic_widget ((GtkLabel *)label, dialog->entry_replace);
 	gtk_misc_set_alignment (GTK_MISC (label), .0, .5);
 	gtk_table_attach (GTK_TABLE (table), label, 0, 1, 1, 2, GTK_FILL, GTK_FILL, 0, 0);
 
@@ -208,7 +219,9 @@ gtk_html_replace_dialog_new (GtkHTML *html, GtkHTMLControlData *cd)
 	gtk_widget_show_all (table);
 	gtk_widget_show_all (hbox);
 
-	gnome_window_icon_set_from_file (GTK_WINDOW (dialog->dialog), ICONDIR "/search-and-replace-24.png");
+	filename = g_build_filename (ICONDIR, "search-and-replace-24.png", NULL);
+	gnome_window_icon_set_from_file (GTK_WINDOW (dialog->dialog), filename);
+	g_free (filename);
 
 	gtk_widget_grab_focus (dialog->entry_search);
 
